<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'swt'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

/* set some defaults */
$theme_dir = get_bloginfo( 'template_directory' );
 
$slider_mode = array(
	'fade' => __('Fade', 'swt'),
	'horizontal' => __('Horizontal', 'swt'),
	'vertical' => __('Vertical', 'swt')
);	

$slider_auto = array(
	'true' => __('Yes', 'swt'),
	'false' => __('No', 'swt')
);	

$slider_autohover = array(
	'true' => __('Yes', 'swt'),
	'false' => __('No', 'swt')
);	
	
// If using image radio buttons, define a directory path
$imagepath =  get_template_directory_uri() . '/admin/images/';

$options = array();

$options[] = array( "name" => __( "General", "swt" ),
					"type" => "heading" );

$options[] = array( "name" => __( "Default Site Layout", "swt" ),
					"desc" => "",
					"id" => "site_layout",
					"std" => "layout-2c-l",
					"type" => "images",
					"options" => array(
								'layout-1c'    => $imagepath . '1col.png',
								'layout-2c-l'  => $imagepath . '2cl.png',
								'layout-2c-r'  => $imagepath . '2cr.png',
								)
					);					
					
$options[] = array( "name" => __( "Header Scripts", "swt" ),
					"desc" => __( "Add scripts before &lt;/head&gt; tag", "swt" ),
					"id" => "header_scripts",					
					"type" => "textarea",
					"std" => "");

$options[] = array( "name" => __( "Footer Scripts", "swt" ),
					"desc" => __( "Add scripts before &lt;/body&gt; tag", "swt" ),
					"id" => "footer_scripts",					
					"type" => "textarea",
					"std" => "");

$options[] = array( "name" => __( "Custom CSS", "swt" ),
					"desc" => __( "Add your own CSS", "swt" ),
					"id" => "custom_css",
					"type" => "textarea",
					"std" => "");    							

$options[] = array( "name" => __( "Upload Favicon (16x16px)", "swt" ),
					"desc" => __( "A favicon (short for Favorite icon), is also known as a shortcut icon, Web site icon, URL icon or bookmark icon, most commonly 16x16 pixels, associated with a particular Web site or Web page. For example, you can generate your 16x16px favicon <a href='http://www.favicongenerator.com/'>here</a>.", "swt" ),
					"id" => "favicon",					
					"type" => "upload",
					"std" => "");	
				
$options[] = array( 'name' => __( "Top Banner", "swt" ),
					'type' => 'heading');	

					
$options[] = array( 'name' => __( "Enable / Disable Top Banner", "swt" ),
					'desc' => __( "Checked - enabled", "swt" ),
					'id' => 'swt_top_banner',
					'std' => '0',
					'type' => 'checkbox' );		
					
$options[] = array( "name" => __( "Upload Banner Image (728x90)", "swt" ),
					"desc" => '',
					"id" => "top_banner_img",					
					"type" => "upload",
					"std" => "{$imagepath}728x90.jpg");											
			
$options[] = array( "name" => __( "Banner URL", "swt" ),
					"desc" => "",
					"id" => "top_banner_url",
					"type" => "text",
					"std" => "#");				
			
$options[] = array( 'name' => __( "Social Profiles", "swt" ),
					'type' => 'heading');	

$options[] = array( 'name' => __( "Enable / Disable Social Profiles", "swt" ),
					'desc' => __( "If enabled, social icons will appear in menu or in sidebar of theme.", "swt" ),
					'id' => 'swt_social_profiles',
					'std' => '0',
					'type' => 'checkbox' );		

$options[] = array( "name" => __( "Facebook URL", "swt" ),
					"desc" => "",
					"id" => "social_facebook",
					"type" => "text",
					"std" => "");			
												
$options[] = array( "name" => __( "Twitter URL", "swt" ),
					"desc" => "",
					"id" => "social_twitter",
					"type" => "text",
					"std" => "");							
					
$options[] = array( "name" => __( "Google Plus URL", "swt" ),
					"desc" => "",
					"id" => "social_gplus",
					"type" => "text",
					"std" => "");		
												
$options[] = array( "name" => __( "Youtube URL", "swt" ),
					"desc" => "",
					"id" => "social_youtube",
					"type" => "text",
					"std" => "");							
					
$options[] = array( "name" => __( "Instagram URL", "swt" ),
					"desc" => "",
					"id" => "social_instagram",
					"type" => "text",
					"std" => "");		

$options[] = array( "name" => __( "Pinterest URL", "swt" ),
					"desc" => "",
					"id" => "social_pinterest",
					"type" => "text",
					"std" => "");		
					

$options[] = array( 'name' => __( "Slider", "swt" ),
					'type' => 'heading');	

$options[] = array( 'name' => __( "How to add posts to content slider?", "swt" ),
					'desc' => __( "First thing - you need to enable content slider by checking \"Enable content slider\" below. Make a new post, and set a featured image for it. Save it, and click on \"All posts\". Find the  post you just made, and click on \"Quick Edit\". Now just click on \"Make this post sticky\" and click \"Update\". Make at least one more post this way, or slider will slide to the same post again and  again.", "swt" ),
					'type' => 'info');    		
	
$options[] = array( 'name' => __( "Content Slider", "swt" ),
					"desc" => __( "Enable content slider (checked - enabled)", "swt" ),
					'id' => 'swt_slider',
					'std' => '0',
					'type' => 'checkbox');		

$options[] = array( 'name' => __( "Type of transition between slides", "swt" ),
					'id' => 'slider_mode',
					'std' => 'fade',
					'type' => 'radio',
					'options' => $slider_mode);							
	
$options[] = array(	'name' => __( "Slides automatically", "swt" ),
					'id' => 'slider_auto',
					'std' => 'true',
					'type' => 'radio',
					'options' => $slider_auto);				
						
						
$options[] = array( "name" => __( "The amount of time (in ms) between each slide", "swt" ),
					"id" => "slider_pause",
					"class" => "mini",							
					"type" => "text",
					"std" => "4000");		
	
return $options;
	
}